# Connecting the UI to a Remote Daemon

_This instructional how-to has been updated and [moved to the wiki](https://github.com/Stor-Network/stor-blockchain/wiki/Connecting-the-UI-to-a-remote-daemon)._
